%global codename fuerte
%global shortname pcl

Name:		ros-%{codename}-pcl
Version:	1.5.2
Release:	0.3.20120530git%{?dist}
Summary:	A ROS specific version of PCL
License:	BSD
URL:		http://ros.org/wiki/pcl
# There is no pre-packaged tarball for this.
# git clone https://github.com/wg-debs/pcl
# mv pcl ros-pcl
# rm -rf ros-pcl/.git
# tar cvfj ros-pcl-20120530git.tar.bz2 ros-pcl
Source0:	ros-pcl-20120530git.tar.bz2
Patch0:		ros-pcl-gcc47.patch
# We need to rename this so it doesn't conflict with "normal" PCL
Patch1:		ros-pcl-rename.patch
BuildRequires:	catkin
BuildRequires:	eigen3-devel, flann-devel, cminpack-devel, vtk-devel, gl2ps-devel
BuildRequires:	ros-%{codename}-ros-devel, ros-%{codename}-common-msgs-devel
BuildRequires:	qhull-devel, libusb1-devel, gtest-devel, mysql-devel
BuildRequires:	cmake, python-sphinx
BuildRequires:	chrpath, boost-devel
Provides:	ros-%{shortname} = %{version}-%{release}

%description
The Point Cloud Library (or PCL) for point cloud processing - development
The PCL framework contains numerous state-of-the art algorithms including
filtering, feature estimation, surface reconstruction, registration, model
fitting and segmentation. This package is customized for ROS.

%package devel
Summary:	Development files for ROS pcl
Requires:	ros-%{codename}-ros-devel, ros-%{codename}-common-msgs-devel
Requires:	eigen3-devel, flann-devel, cminpack-devel, vtk-devel, gl2ps-devel
Requires:	qhull-devel, libusb1-devel, gtest-devel, mysql-devel, boost-devel
Requires:	%{name} = %{version}-%{release}
Provides:	ros-%{shortname}-devel = %{version}-%{release}

%description devel
Development files for ROS pcl.

%prep
%setup -q -c
%patch0 -p1 -b .gcc47
%patch1 -p1 -b .rename

%build
cd ros-%{shortname}
mkdir build
pushd build
source /etc/catkin/profile.d/10.ros.all
%cmake \
  -DCMAKE_BUILD_TYPE=Release \
  -DLIB_INSTALL_DIR=$(echo %{_libdir} | sed -e 's|%{_prefix}/||') \
  -DPCL_PKGCONFIG_SUFFIX:STRING="" \
  -DCMAKE_SKIP_RPATH=ON \
  -DBUILD_documentation=OFF \
  -DSETUPTOOLS_DEB_LAYOUT=OFF \
  -DUSE_ROS=ON \
  ..
make %{?_smp_mflags}
popd

%install
cd ros-%{shortname}
mkdir -p %{buildroot}%{_datadir}/ros-stacks/pcl
pushd build
make DESTDIR=%{buildroot} install
popd

mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/
cp -a stack.yaml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/

# We're not going to package the binaries here, unless we end up needing them.
rm -rf %{buildroot}%{_bindir}

# We're also not going to package the tutorials here, they're identical to the normal PCL ones.
rm -rf %{buildroot}%{_datadir}/doc/*/tutorials

# We're moving the headers into /usr/include/ros-pcl-1.5
mv %{buildroot}%{_includedir}/pcl-1.5 %{buildroot}%{_includedir}/ros-pcl-1.5

# Fixup the cmake.
sed -i 's|pcl_|ros_pcl_|g' %{buildroot}%{_datadir}/pcl-1.5/PCLConfig.cmake
sed -i 's|include/pcl|include/ros-pcl|g' %{buildroot}%{_datadir}/pcl-1.5/PCLConfig.cmake
sed -i 's|PCL_|ROS_PCL_|g' %{buildroot}%{_datadir}/pcl-1.5/PCLConfig.cmake
sed -i 's|pcl-|ros-pcl-|g' %{buildroot}%{_datadir}/pcl-1.5/PCLConfig.cmake
sed -i 's|PCLC|ROS_PCLC|g' %{buildroot}%{_datadir}/pcl-1.5/PCLConfig.cmake
sed -i 's|ros-ros|ros|g' %{buildroot}%{_datadir}/pcl-1.5/PCLConfig.cmake
sed -i 's|ros_pcl_config.h|pcl_config.h|g' %{buildroot}%{_datadir}/pcl-1.5/PCLConfig.cmake
mv %{buildroot}%{_datadir}/pcl-1.5/ %{buildroot}%{_datadir}/ros_pcl-1.5/
mv %{buildroot}%{_datadir}/ros_pcl-1.5/PCLConfig.cmake %{buildroot}%{_datadir}/ros_pcl-1.5/ROS_PCLConfig.cmake
mv %{buildroot}%{_datadir}/ros_pcl-1.5/PCLConfigVersion.cmake %{buildroot}%{_datadir}/ros_pcl-1.5/ROS_PCLConfigVersion.cmake

# Fixup the pkgconfig files
sed -i 's|include/pcl-1.5|include/ros-pcl-1.5/|g' %{buildroot}%{_libdir}/pkgconfig/ros_pcl_*.pc

mv %{buildroot}%{_datadir}/pcl/* %{buildroot}%{_datadir}/ros-stacks/pcl/

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc ros-pcl/AUTHORS.txt ros-pcl/LICENSE.txt
%{_datadir}/ros-stacks/pcl/
%{_libdir}/libros_pcl_*.so.*

%files devel
%{_includedir}/ros-pcl-1.5/
%{_datadir}/ros_pcl-1.5/ROS_PCLConfig*.cmake
%{_libdir}/libros_pcl_*.so
%{_libdir}/pkgconfig/ros_pcl_*.pc

%changelog
* Fri Jun  1 2012 Tom Callaway <spot@fedoraproject.org> - 1.5.2-0.3.20120530git
- more rename changes

* Wed May 30 2012 Tom Callaway <spot@fedoraproject.org> - 1.5.2-0.2.20120530git
- fixup cmake

* Wed May 30 2012 Tom Callaway <spot@fedoraproject.org> - 1.5.2-0.1.20120530git
- initial package
